==> dsfr-2.1.10-rc2.tar.gz: dsfr/src/Dsfr.php <==
<?php

namespace Drupal\dsfr;

class Dsfr {

  /**
   * Tabs for theme settings forms
   */
  public static function theme( $theme = 'dsfr' ) {

    // For Child theme
    $theme_path = base_path() . 'themes/contrib/' . $theme;
    $dist = $theme_path . '/dist/';

    $theme_current = \Drupal::config('system.theme')->get('default');
    $theme_path_current = base_path() . 'themes/contrib/' . $theme_current;
    $dist_current = $theme_path_current . '/dist/';    

    // Get MAIN url
    $https = (isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https' && $_SERVER["REQUEST_SCHEME"] == 'http') ? 'https://' : 'http://';

    // Default container
    $container = 'fr-container';

    // Breadcrumb position
    switch(theme_get_setting('breadcrumb.position')) {
      case '1': $breadcrumb_position = ' rf-breadcrumb--center'; break;
      case '2': $breadcrumb_position = ' rf-breadcrumb--right'; break;
      default: $breadcrumb_position = '';
    }

    $important_message = (theme_get_setting('info_important.message')) ? theme_get_setting('info_important.message') : '';

    return [

      'domain'    => $https . $_SERVER['HTTP_HOST'],
      'name'      => $theme_current,
      'path'      => $theme_path_current,
      'dist'      => $dist_current,
      'favicons'  => $dist_current. 'dsfr/favicon/',
      'img'       => $dist_current. 'img/',
      'lib'       => $dist . 'dsfr/',
      'dsfr'      => [
        'name'    => $theme,
        'path'    => $theme_path,
        'dist'    => $dist,
        'favicons'=> $dist . 'dsfr/favicon/',
        //'img'     => $dist . 'img/',
      ],
      'general'   => [
        'institution' => (theme_get_setting('general.institution')) ? theme_get_setting('general.institution') : 'République <br> Française'
      ],
      'header'    => [
        'container' => (theme_get_setting('header.container')) ? $container . '-fluid' : $container,
        'logo'    => [
          'img'   => theme_get_setting('header.logo.img'),
          'text'   => theme_get_setting('header.logo.text')
        ],
        'settings' => theme_get_setting('header.settings'),     
      ],
      'navigation'  => [
        'container' => (theme_get_setting('navigation.container')) ? $container . '-fluid' : $container,
      ],
      'info_important' => [
        'message' => $important_message,
        'show' => theme_get_setting('info_important.show'),
        'close' => theme_get_setting('info_important.close')
      ],
      'hero' => [
        'container' => (theme_get_setting('hero.container')) ? $container . '-fluid' : $container,
        'margin' => [
          'top'     => theme_get_setting('hero.margin.top'),
          'bottom'  => theme_get_setting('hero.margin.bottom')
        ]
      ],
      'breadcrumb' => [
        //'container' => (theme_get_setting('breadcrumb.container')) ? $container . '-fluid' : $container,
        'position'  => $breadcrumb_position,
      ],
      'content' => [
        'container' => (theme_get_setting('content.container')) ? $container . '-fluid' : $container,
        'margin' => [
          'top'     => theme_get_setting('content.margin.top'),
          'bottom'  => theme_get_setting('content.margin.bottom')
        ]
      ],
      'footer_top' => [
        'container' => (theme_get_setting('footer_top.container')) ? $container . '-fluid' : $container,
      ],
      'footer' => [
        'container' => (theme_get_setting('footer.container')) ? $container . '-fluid' : $container,
        'logo' => [
          'img' => theme_get_setting('footer.logo.img')
        ],
        'last_line' => theme_get_setting('footer.last_line')
      ], 
      'code'   => [
        'gdpr' => theme_get_setting('code.gdpr'),
        'newsletter' => theme_get_setting('code.newsletter'),
        'w3c' => theme_get_setting('code.w3c')
      ],
      'features' => [
        'node_user_picture' => theme_get_setting('features.node_user_picture'),
        'comment_user_picture' => theme_get_setting('features.comment_user_picture'),
        'comment_user_verification' => theme_get_setting('features.comment_user_verification'),
        'favicon' => theme_get_setting('features.favicon')
      ],
      'logo' => [
        'use_default' => theme_get_setting('logo.use_default'),
        'path'        => theme_get_setting('logo.path')
      ],
      'favicon' => [
        'use_default' => theme_get_setting('favicon.use_default'),
        'path'        => theme_get_setting('favicon.path')
      ]
    ];
  }

  /**
   * Get a global configuration of the site
   */
  public static function siteConfig() {

    $config = \Drupal::config('system.site');

    return [
      'name'    => $config->get('name'),
      'slogan'  => $config->get('slogan'),
    ];
  }

  /**
   * Get URL
   */
  public static function getUrl() {

    $current = \Drupal::service('path.current')->getPath();
    
    $current_clean = str_replace('/', '-', $current);
    $current_clean = substr($current_clean, 1);

    return [
      'front'   => \Drupal::service('path.matcher')->isFrontPage(),
      'current' => $current,
      'current_clean' => $current_clean
    ];
  }
}

==> dsfr-2.1.11-rc2.tar.gz: dsfr/src/Dsfr.php <==
<?php

namespace Drupal\dsfr;

use Drupal\Core\Database\Database;

class Dsfr {

  /**
   * Tabs for theme settings forms
   */
  public static function theme( $theme = 'dsfr' ) {

    $base_url = base_path();
    $theme_current = \Drupal::config('system.theme')->get('default');
    $theme_path_current = $base_url . \Drupal::theme()->getActiveTheme()->getPath();
    $dist_current = $theme_path_current . '/dist/';    
    
    // ************************************************************* //
    // DSRF librarie

    $external_lib = theme_get_setting('code.external_lib');

    // Components
    $dsfr = [];
    $components = [
      'accordion',
      'alert',
      'badge',
      'breadcrumb',
      'button' ,
      'callout',
      'card',
      'checkbox',
      'connect',
      'consent',
      'content',
      'display',
      'download',
      'follow',
      'footer',
      'form',
      'header',
      'highlight',
      'input',
      'link',
      'logo',
      'modal',
      'navigation',
      'notice',
      'pagination',
      'quote',
      'radio',
      'search',
      'segmented',
      'select',
      'share',
      'sidemenu',
      'skiplink',
      'stepper',
      'summary',
      'tab',
      'table',
      'tag',
      'tile',
      'toggle',
      'tooltip',
      'transcription',
      'translate',
      'upload',
      'utility', 
    ];

    // Init special component
    $dsfr['components']['notice'] = [
      'check' => false,
      'message' => '<strong>Lorem</strong> ipsum',
      'date_start' => time(),
      'date_end' => NULL,
      'close' => false,
    ];
    $dsfr['components']['enabled'] = 0;

    $dsfr['components']['count'] = count( $components );

    if( $external_lib == 0 ) {

      $n = 0;

      foreach( $components as $component ) {
  
        $value = 'code.components.'.$component;
  
        if( theme_get_setting($value) == 1) {
  
          $dsfr['components'][$component]['lib'] = true;
          $n++;
          $dsfr['components']['enabled'] = $n;
        }
      }
    }

    // ************************************************************* //
    // SEE: dsfr_block module on drupal.org
    $table_notice = 'dsfr_block_notice';
    $db = Database::getConnection();

    if ( $db->schema()->tableExists( $table_notice )) {

      $data = $db
      ->query("SELECT * FROM $table_notice WHERE id='1'")
      ->fetchAll();

      if( count( $data ) > 0 ) {

        $dsfr['components']['notice'] = [
          'check' => true,
          'message' => $data[0]->message,
          'date_start' => strtotime($data[0]->date_start),
          'date_end' => strtotime($data[0]->date_end),
          'close' => $data[0]->close
        ];
      }
    } 

    // ************************************************************* //
    // Legacy for Child theme
    $theme_path = $base_url . 'themes/contrib/dsfr';
    $dist = $theme_path . '/dist/';

    // Get MAIN url
    $https = (isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https' && $_SERVER["REQUEST_SCHEME"] == 'http') ? 'https://' : 'http://';

    // Default container
    $container = 'fr-container';

    // Breadcrumb position
    switch(theme_get_setting('breadcrumb.position')) {
      case '1': $breadcrumb_position = ' rf-breadcrumb--center'; break;
      case '2': $breadcrumb_position = ' rf-breadcrumb--right'; break;
      default: $breadcrumb_position = '';
    }

    $important_message = (theme_get_setting('info_important.message')) ? theme_get_setting('info_important.message') : '';

    // Final result
    return [

      'domain'    => $https . $_SERVER['HTTP_HOST'],
      'name'      => $theme_current,
      'path'      => $theme_path_current,
      'dist'      => $dist_current,
      'favicons'  => $dist_current. 'dsfr/favicon/',
      'img'       => $dist_current. 'img/',
      'lib'       => $dist . 'dsfr/',
      'dsfr'      => [
        'name'    => $theme,
        'path'    => $theme_path,
        'dist'    => $dist,
        'favicons'=> $dist . 'dsfr/favicon/',
        'img'     => $dist . 'img/',
        'lib'     => $dist . 'dsfr/',
        'components' => $dsfr['components'],
        'external'=> $external_lib
      ],
      'general'   => [
        'institution' => (theme_get_setting('general.institution')) ? theme_get_setting('general.institution') : 'République <br> Française'
      ],
      'header'    => [
        'container' => (theme_get_setting('header.container')) ? $container . '-fluid' : $container,
        'logo'    => [
          'img'   => theme_get_setting('header.logo.img'),
          'text'   => theme_get_setting('header.logo.text')
        ],
        'settings' => theme_get_setting('header.settings'),     
      ],
      'navigation'  => [
        'container' => (theme_get_setting('navigation.container')) ? $container . '-fluid' : $container,
      ],
      'info_important' => [
        'message' => $important_message,
        'show' => theme_get_setting('info_important.show'),
        'close' => theme_get_setting('info_important.close')
      ],
      'hero' => [
        'container' => (theme_get_setting('hero.container')) ? $container . '-fluid' : $container,
        'margin' => [
          'top'     => theme_get_setting('hero.margin.top'),
          'bottom'  => theme_get_setting('hero.margin.bottom')
        ]
      ],
      'breadcrumb' => [
        //'container' => (theme_get_setting('breadcrumb.container')) ? $container . '-fluid' : $container,
        'position'  => $breadcrumb_position,
      ],
      'content' => [
        'container' => (theme_get_setting('content.container')) ? $container . '-fluid' : $container,
        'margin' => [
          'top'     => theme_get_setting('content.margin.top'),
          'bottom'  => theme_get_setting('content.margin.bottom')
        ]
      ],
      'footer_top' => [
        'container' => (theme_get_setting('footer_top.container')) ? $container . '-fluid' : $container,
      ],
      'footer' => [
        'container' => (theme_get_setting('footer.container')) ? $container . '-fluid' : $container,
        'logo' => [
          'img' => theme_get_setting('footer.logo.img')
        ],
        'last_line' => theme_get_setting('footer.last_line')
      ], 
      'code'   => [
        'gdpr' => theme_get_setting('code.gdpr'),
        'newsletter' => theme_get_setting('code.newsletter'),
        'w3c' => theme_get_setting('code.w3c')
      ],
      'features' => [
        'node_user_picture' => theme_get_setting('features.node_user_picture'),
        'comment_user_picture' => theme_get_setting('features.comment_user_picture'),
        'comment_user_verification' => theme_get_setting('features.comment_user_verification'),
        'favicon' => theme_get_setting('features.favicon')
      ],
      'logo' => [
        'use_default' => theme_get_setting('logo.use_default'),
        'path'        => theme_get_setting('logo.path')
      ],
      'favicon' => [
        'use_default' => theme_get_setting('favicon.use_default'),
        'path'        => theme_get_setting('favicon.path')
      ]
    ];
  }

  /**
   * Get a global configuration of the site
   */
  public static function siteConfig() {

    $config = \Drupal::config('system.site');

    return [
      'name'    => $config->get('name'),
      'slogan'  => $config->get('slogan'),
    ];
  }

  /**
   * Get URL
   */
  public static function getUrl() {

    $current = \Drupal::service('path.current')->getPath();
    
    $current_clean = str_replace('/', '-', $current);
    $current_clean = substr($current_clean, 1);

    return [
      'front'   => \Drupal::service('path.matcher')->isFrontPage(),
      'current' => $current,
      'current_clean' => $current_clean
    ];
  }
}
